==> kubernetes-model-gatewayapi-6.1.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayTLSConfigFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayTLSConfigFluent<A extends GatewayTLSConfigFluent<A>> extends Fluent<A>{
  public A addToCertificateRefs(Integer index,SecretObjectReference item);
  public A setToCertificateRefs(Integer index,SecretObjectReference item);
  public A addToCertificateRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.SecretObjectReference... items);
  public A addAllToCertificateRefs(Collection<SecretObjectReference> items);
  public A removeFromCertificateRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.SecretObjectReference... items);
  public A removeAllFromCertificateRefs(Collection<SecretObjectReference> items);
  public A removeMatchingFromCertificateRefs(Predicate<SecretObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCertificateRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SecretObjectReference> getCertificateRefs();
  public List<SecretObjectReference> buildCertificateRefs();
  public SecretObjectReference buildCertificateRef(Integer index);
  public SecretObjectReference buildFirstCertificateRef();
  public SecretObjectReference buildLastCertificateRef();
  public SecretObjectReference buildMatchingCertificateRef(Predicate<SecretObjectReferenceBuilder> predicate);
  public Boolean hasMatchingCertificateRef(Predicate<SecretObjectReferenceBuilder> predicate);
  public A withCertificateRefs(List<SecretObjectReference> certificateRefs);
  public A withCertificateRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.SecretObjectReference... certificateRefs);
  public Boolean hasCertificateRefs();
  public A addNewCertificateRef(String group,String kind,String name,String namespace);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> addNewCertificateRef();
  public GatewayTLSConfigFluent.CertificateRefsNested<A> addNewCertificateRefLike(SecretObjectReference item);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> setNewCertificateRefLike(Integer index,SecretObjectReference item);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editCertificateRef(Integer index);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editFirstCertificateRef();
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editLastCertificateRef();
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editMatchingCertificateRef(Predicate<SecretObjectReferenceBuilder> predicate);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  public A addToOptions(String key,String value);
  public A addToOptions(Map<String,String> map);
  public A removeFromOptions(String key);
  public A removeFromOptions(Map<String,String> map);
  public Map<String,String> getOptions();
  public <K,V>A withOptions(Map<String,String> options);
  public Boolean hasOptions();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CertificateRefsNested<N> extends Nested<N>,SecretObjectReferenceFluent<GatewayTLSConfigFluent.CertificateRefsNested<N>>{
    public N and();
    public N endCertificateRef();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayTLSConfigFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayTLSConfigFluent<A extends GatewayTLSConfigFluent<A>> extends Fluent<A>{
  public A addToCertificateRefs(int index,SecretObjectReference item);
  public A setToCertificateRefs(int index,SecretObjectReference item);
  public A addToCertificateRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.SecretObjectReference... items);
  public A addAllToCertificateRefs(Collection<SecretObjectReference> items);
  public A removeFromCertificateRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.SecretObjectReference... items);
  public A removeAllFromCertificateRefs(Collection<SecretObjectReference> items);
  public A removeMatchingFromCertificateRefs(Predicate<SecretObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCertificateRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SecretObjectReference> getCertificateRefs();
  public List<SecretObjectReference> buildCertificateRefs();
  public SecretObjectReference buildCertificateRef(int index);
  public SecretObjectReference buildFirstCertificateRef();
  public SecretObjectReference buildLastCertificateRef();
  public SecretObjectReference buildMatchingCertificateRef(Predicate<SecretObjectReferenceBuilder> predicate);
  public Boolean hasMatchingCertificateRef(Predicate<SecretObjectReferenceBuilder> predicate);
  public A withCertificateRefs(List<SecretObjectReference> certificateRefs);
  public A withCertificateRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.SecretObjectReference... certificateRefs);
  public Boolean hasCertificateRefs();
  public A addNewCertificateRef(String group,String kind,String name,String namespace);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> addNewCertificateRef();
  public GatewayTLSConfigFluent.CertificateRefsNested<A> addNewCertificateRefLike(SecretObjectReference item);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> setNewCertificateRefLike(int index,SecretObjectReference item);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editCertificateRef(int index);
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editFirstCertificateRef();
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editLastCertificateRef();
  public GatewayTLSConfigFluent.CertificateRefsNested<A> editMatchingCertificateRef(Predicate<SecretObjectReferenceBuilder> predicate);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  public A addToOptions(String key,String value);
  public A addToOptions(Map<String,String> map);
  public A removeFromOptions(String key);
  public A removeFromOptions(Map<String,String> map);
  public Map<String,String> getOptions();
  public <K,V>A withOptions(Map<String,String> options);
  public Boolean hasOptions();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CertificateRefsNested<N> extends Nested<N>,SecretObjectReferenceFluent<GatewayTLSConfigFluent.CertificateRefsNested<N>>{
    public N and();
    public N endCertificateRef();
    
  }
  
}
